HyperLogLog8Builder

Struct HyperLogLog8Builder 

pub struct HyperLogLog8Builder<H, const BETA: bool = true> { /* private fields */ }
Builder for HyperLogLog8 cardinality-estimation logic.

The builder lets you configure:

Call build to obtain the configured HyperLogLog8 logic.

Implementations

Source

impl HyperLogLog8Builder<BuildHasherDefault<DefaultHasher>>

pub const fn new() -> Self

Creates a new builder for a HyperLogLog8 logic.

Source

impl<H, const BETA: bool> HyperLogLog8Builder<H, BETA>

pub fn rsd(self, rsd: f64) -> Self

Sets the desired relative standard deviation.

This is a high-level alternative to Self::log2_num_regs. Calling one after the other invalidates the work done by the first one.

Arguments
  • rsd: the relative standard deviation to be attained.
Panics

If the resulting number of registers is less than 16 (i.e., rsd is too large).

pub const fn log2_num_regs(self, log2_num_regs: u32) -> Self

Sets the base-2 logarithm of the number of registers.

This is a low-level alternative to Self::rsd. Calling one after the other invalidates the work done by the first one.

Arguments
  • log2_num_regs: the logarithm of the number of registers per estimator.
Panics

If log2_num_regs is less than 4.

pub fn beta<const BETA2: bool>(self) -> HyperLogLog8Builder<H, BETA2>

Enables or disables the LogLog-β bias correction in the estimate.

See HyperLogLog8 for details.

pub fn build_hasher<H2>(self, build_hasher: H2) -> HyperLogLog8Builder<H2, BETA>

Sets the BuildHasher to use.

Using this method you can select a specific hasher based on one or more seeds.

pub fn build<T>(self) -> HyperLogLog8<T, H, BETA>

Builds the logic.

The type of objects the estimators keep track of is defined here by T, but it is usually inferred by the compiler.