pub struct SliceEstimatorArray<L, W = usize, S = Box<[W]>> { /* private fields */ }Expand description
An array for estimators implementing a shared EstimationLogic, and whose
backend is a slice.
Note that we need a specific type for arrays of slice backends as one cannot create a slice of slices.
Implementations