SliceEstimationLogic

Trait SliceEstimationLogic 

pub trait SliceEstimationLogic<T>: EstimationLogic<Backend = [T]> {
    // Required method
    fn backend_len(&self) -> usize;
}
Trait implemented by estimation logics whose backend is a slice of elements of some type.

Required Methods

fn backend_len(&self) -> usize

The number of elements of type T in a backend.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: Hash, H: BuildHasher + Clone, W: Word, const BETA: bool> SliceEstimationLogic<W> for HyperLogLog<T, H, W, BETA>

Source

impl<T: Hash, H: BuildHasher + Clone, const BETA: bool> SliceEstimationLogic<u8> for HyperLogLog8<T, H, BETA>