pub trait Word: PrimitiveUnsigned {
const ZERO: Self;
const ONE: Self;
}Expand description
A convenience trait bundling the bounds required for word types used as
backends for estimators, plus constants for zero and one (which avoid a
dependence from the num-traits
crate).
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".