pub fn beta_horner(z: f64, log2_num_regs: usize) -> f64Expand description
Computes the LogLog-β bias correction using Horner’s method.
The method appears in the paper from Jason Qin, Denys Kim & Yumei Tung, “LogLog-Beta and More: A New Algorithm for Cardinality Estimation Based on LogLog Counting”, 2016.
Panics
If log2_num_regs is not in [4 . . 18].